# -*- coding: utf-8 -*-

from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
from django.utils.translation import ugettext_lazy as _

from wagtail.wagtailadmin.edit_handlers import StreamFieldPanel
from wagtail.wagtailcore.fields import StreamField
from wagtail.wagtailcore.blocks import RichTextBlock

from texsite.core.models import BasePage
from texsite.core.blocks import HeadingBlock, ImageBlock, IntroBlock, QuoteBlock


class CleanBlogArticlePage(BasePage):
    """Clean blog article page"""
    # Page model fields
    body = StreamField([
        ('intro', IntroBlock(template='texsitecleanblog/blocks/intro.html')),
        ('heading', HeadingBlock(template='texsitecleanblog/blocks/heading.html')),
        ('paragraph', RichTextBlock()),
        ('image', ImageBlock(template='texsitecleanblog/blocks/image.html')),
        ('quote', QuoteBlock(template='texsitecleanblog/blocks/quote.html')),
    ])

    # Editor interface configuration
    content_panels = BasePage.content_panels + [
        StreamFieldPanel('body'),
    ]

    class Meta:
        verbose_name = _('Clean Blog Article Page') + ' (' + __package__ + ')'


class CleanBlogArticleIndexPage(BasePage):
    """Clean blog article index page"""
    # Page model fields
    body = StreamField([
        ('intro', IntroBlock(template='texsitecleanblog/blocks/intro.html')),
    ])

    @property
    def articles(self):
        # Get list of live article pages that are descendants of this page by sort order
        return CleanBlogArticlePage.objects.live().descendant_of(self).order_by('path')

    def get_context(self, request):
        # Get articles
        articles = self.articles

        # Pagination
        page = request.GET.get('page')
        paginator = Paginator(articles, 4)

        try:
            articles = paginator.page(page)
        except PageNotAnInteger:
            articles = paginator.page(1)
        except EmptyPage:
            articles = paginator.page(paginator.num_pages)

        # Update template context
        context = super(CleanBlogArticleIndexPage, self).get_context(request)
        context['articles'] = articles

        return context

    # Editor interface configuration
    content_panels = BasePage.content_panels + [
        StreamFieldPanel('body'),
    ]

    class Meta:
        verbose_name = _('Clean Blog Article Index Page') + ' (' + __package__ + ')'



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import wagtail.wagtailcore.fields
import wagtail.wagtailcore.blocks
import wagtail.wagtailimages.blocks

import json


def convert_to_imageblock(apps, schema_editor):
    CleanBlogArticlePage = apps.get_model("texsitecleanblog", "CleanBlogArticlePage")

    for page in CleanBlogArticlePage.objects.all():
        new_stream_data = []

        for block in page.body.stream_data:
            if block["type"] == "image":
                extendedimage = {
                    "type": "extendedimage",
                    "value": {
                        "image": block["value"]
                    }
                }
                new_stream_data.append(extendedimage)
            else:
                new_stream_data.append(block)

        page.body = json.dumps(new_stream_data)
        page.save()


def rename_imageblock(apps, schema_editor):
    CleanBlogArticlePage = apps.get_model("texsitecleanblog", "CleanBlogArticlePage")

    for page in CleanBlogArticlePage.objects.all():
        new_stream_data = []

        for block in page.body.stream_data:
            if block["type"] == "extendedimage":
                block["type"] = "image"

            new_stream_data.append(block)

        page.body = json.dumps(new_stream_data)
        page.save()


def noop(apps, schema_editor):
    pass


class Migration(migrations.Migration):

    dependencies = [
        ('texsitecleanblog', '0002_add_quote_block'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cleanblogarticlepage',
            name='body',
            field=wagtail.wagtailcore.fields.StreamField([(b'intro', wagtail.wagtailcore.blocks.StructBlock([(b'keyvisual', wagtail.wagtailimages.blocks.ImageChooserBlock(required=False)), (b'slogan', wagtail.wagtailcore.blocks.CharBlock(required=True))])), (b'heading', wagtail.wagtailcore.blocks.StructBlock([(b'title', wagtail.wagtailcore.blocks.CharBlock(required=True)), (b'subtitle', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/heading.html')), (b'paragraph', wagtail.wagtailcore.blocks.RichTextBlock()), (b'image', wagtail.wagtailimages.blocks.ImageChooserBlock(template=b'texsitecleanblog/blocks/image.html')), (b'extendedimage', wagtail.wagtailcore.blocks.StructBlock([(b'image', wagtail.wagtailimages.blocks.ImageChooserBlock(required=True)), (b'caption', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/image.html')), (b'quote', wagtail.wagtailcore.blocks.StructBlock([(b'quote', wagtail.wagtailcore.blocks.TextBlock(required=True)), (b'originator', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/quote.html'))]),
        ),
        migrations.RunPython(
            convert_to_imageblock,
            noop,
        ),
        migrations.AlterField(
            model_name='cleanblogarticlepage',
            name='body',
            field=wagtail.wagtailcore.fields.StreamField([(b'intro', wagtail.wagtailcore.blocks.StructBlock([(b'keyvisual', wagtail.wagtailimages.blocks.ImageChooserBlock(required=False)), (b'slogan', wagtail.wagtailcore.blocks.CharBlock(required=True))])), (b'heading', wagtail.wagtailcore.blocks.StructBlock([(b'title', wagtail.wagtailcore.blocks.CharBlock(required=True)), (b'subtitle', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/heading.html')), (b'paragraph', wagtail.wagtailcore.blocks.RichTextBlock()), (b'image', wagtail.wagtailcore.blocks.StructBlock([(b'image', wagtail.wagtailimages.blocks.ImageChooserBlock(required=True)), (b'caption', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/image.html')), (b'extendedimage', wagtail.wagtailcore.blocks.StructBlock([(b'image', wagtail.wagtailimages.blocks.ImageChooserBlock(required=True)), (b'caption', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/image.html')), (b'quote', wagtail.wagtailcore.blocks.StructBlock([(b'quote', wagtail.wagtailcore.blocks.TextBlock(required=True)), (b'originator', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/quote.html'))]),
        ),
        migrations.RunPython(
            rename_imageblock,
            noop,
        ),
        migrations.AlterField(
            model_name='cleanblogarticlepage',
            name='body',
            field=wagtail.wagtailcore.fields.StreamField([(b'intro', wagtail.wagtailcore.blocks.StructBlock([(b'keyvisual', wagtail.wagtailimages.blocks.ImageChooserBlock(required=False)), (b'slogan', wagtail.wagtailcore.blocks.CharBlock(required=True))])), (b'heading', wagtail.wagtailcore.blocks.StructBlock([(b'title', wagtail.wagtailcore.blocks.CharBlock(required=True)), (b'subtitle', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/heading.html')), (b'paragraph', wagtail.wagtailcore.blocks.RichTextBlock()), (b'image', wagtail.wagtailcore.blocks.StructBlock([(b'image', wagtail.wagtailimages.blocks.ImageChooserBlock(required=True)), (b'caption', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/image.html')), (b'quote', wagtail.wagtailcore.blocks.StructBlock([(b'quote', wagtail.wagtailcore.blocks.TextBlock(required=True)), (b'originator', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/quote.html'))]),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import wagtail.wagtailcore.fields
import wagtail.wagtailcore.blocks
import wagtail.wagtailimages.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('texsitecore', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CleanBlogArticlePage',
            fields=[
                ('basepage_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='texsitecore.BasePage')),
                ('body', wagtail.wagtailcore.fields.StreamField([(b'intro', wagtail.wagtailcore.blocks.StructBlock([(b'keyvisual', wagtail.wagtailimages.blocks.ImageChooserBlock(required=False)), (b'slogan', wagtail.wagtailcore.blocks.CharBlock(required=True))])), (b'heading', wagtail.wagtailcore.blocks.StructBlock([(b'title', wagtail.wagtailcore.blocks.CharBlock(required=True)), (b'subtitle', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/heading.html')), (b'paragraph', wagtail.wagtailcore.blocks.RichTextBlock()), (b'image', wagtail.wagtailimages.blocks.ImageChooserBlock(template=b'texsitecleanblog/blocks/image.html'))])),
            ],
            options={
                'verbose_name': 'Clean Blog Article Page (texsite.cleanblog)',
            },
            bases=('texsitecore.basepage',),
        ),
    ]



# -*- coding: utf-8 -*-

from django.core.exceptions import ObjectDoesNotExist

from ..tests import TexsiteTestCase
from texsite.cleanblog.models import CleanBlogArticleIndexPage, CleanBlogArticlePage


class CleanBlogTestCase(TexsiteTestCase):
    def setUp(self):
        super(CleanBlogTestCase, self).setUp()

        try:
            self.article_index_page = CleanBlogArticleIndexPage.objects.get(pk=2)
            self.article_page = CleanBlogArticlePage.objects.get(pk=3)
            self.article_page_two = CleanBlogArticlePage.objects.get(pk=4)
        except ObjectDoesNotExist:
            pass

        self.article_index_page_response = self.client.get('/article-index-page/')
        self.article_page_response = self.client.get('/article-index-page/article-page/')


class CleanBlogStandaloneArticleIndexPageTest(CleanBlogTestCase):
    fixtures = ['site.json', 'cleanblogarticleindex.json']

    def test_article_index_empty_rendered(self):
        self.assertInHTML('<p>No entries found</p>', str(self.article_index_page_response.content))

    def test_article_index_articles_property_returns_zero_child_pages(self):
        self.assertEqual(len(self.article_index_page.articles), 0)

    def test_article_index_has_articles_paginator_in_context(self):
        self.assertEqual(self.article_index_page_response.status_code, 200)
        self.assertEqual(self.article_index_page_response.context['articles'].has_other_pages(), False)

    def test_article_index_with_wrong_page_number_succeeds(self):
        article_index_page_response = self.client.get('/article-index-page/?page=0')
        self.assertEqual(article_index_page_response.status_code, 200)


class CleanBlogArticlePageTest(CleanBlogTestCase):
    fixtures = ['site.json', 'cleanblogarticleindex.json', 'cleanblogarticle.json']

    def test_article_index_articles_property_returns_num_child_page(self):
        num_child_pages = CleanBlogArticlePage.objects.live().descendant_of(self.article_index_page).count()
        self.assertEqual(num_child_pages, 2)
        self.assertEqual(num_child_pages, len(self.article_index_page.articles))

    def test_article_knows_next_sibling(self):
        self.assertEqual(self.article_page.next_sibling.specific, self.article_page_two)

    def test_article_knows_previous_sibling(self):
        self.assertEqual(self.article_page_two.previous_sibling.specific, self.article_page)



# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _

from wagtail.wagtailcore.models import Page


class BasePage(Page):
    """Abstract base page for all texsite pages"""
    is_creatable = False

    @property
    def next_sibling(self):
        # Get next live sibling page by sort order
        return self.get_next_siblings().live().first()

    @property
    def previous_sibling(self):
        # Get previous live sibling page by sort order
        return self.get_prev_siblings().live().first()

    class Meta:
        verbose_name = _('Base Page') + ' (' + __package__ + ')'



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0016_change_page_url_path_to_text_field'),
    ]

    operations = [
        migrations.CreateModel(
            name='BasePage',
            fields=[
                ('page_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
            ],
            options={
                'verbose_name': 'Base Page (texsite.core)',
            },
            bases=('wagtailcore.page',),
        ),
    ]



# -*- coding: utf-8 -*-

from wagtail.wagtailcore.blocks import CharBlock, EmailBlock, ListBlock, RichTextBlock, StructBlock
from wagtail.wagtaildocs.blocks import DocumentChooserBlock
from wagtail.wagtailimages.blocks import ImageChooserBlock


class ContactBlock(StructBlock):
    heading = CharBlock(required=True)
    map = CharBlock(required=False)
    name = CharBlock(required=True)
    phone = CharBlock(required=False)
    mail = EmailBlock(required=False)
    bank = CharBlock(required=False)

    class Meta:
        icon = 'site'
        template = 'texsitebusinesscasual/blocks/contact.html'


class ContentBlock(StructBlock):
    heading = CharBlock(required=True)
    image = ImageChooserBlock(required=False)
    paragraph = RichTextBlock(required=True)

    class Meta:
        icon = 'placeholder'
        template = 'texsitebusinesscasual/blocks/content.html'


class DocumentsBlock(StructBlock):
    heading = CharBlock(required=True)
    paragraph = RichTextBlock(required=False)
    files = ListBlock(DocumentChooserBlock(), template="texsitebusinesscasual/blocks/documentlist.html")

    class Meta:
        icon = 'doc-full'
        template = 'texsitebusinesscasual/blocks/documents.html'


class PersonBlock(StructBlock):
    name = CharBlock(required=True)
    image = ImageChooserBlock(required=True)
    position = CharBlock(required=False)


class PeopleBlock(StructBlock):
    heading = CharBlock(required=True)
    paragraph = RichTextBlock(required=False)
    people = ListBlock(PersonBlock(), template="texsitebusinesscasual/blocks/peoplelist.html")

    class Meta:
        icon = 'user'
        template = 'texsitebusinesscasual/blocks/people.html'



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import wagtail.wagtailimages.blocks
import wagtail.wagtailcore.blocks
import wagtail.wagtailcore.fields


class Migration(migrations.Migration):

    dependencies = [
        ('texsitecore', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='BusinessCasualPage',
            fields=[
                ('basepage_ptr', models.OneToOneField(to='texsitecore.BasePage', primary_key=True, parent_link=True, serialize=False, auto_created=True)),
                ('body', wagtail.wagtailcore.fields.StreamField((('content', wagtail.wagtailcore.blocks.StructBlock((('heading', wagtail.wagtailcore.blocks.CharBlock(required=True)), ('image', wagtail.wagtailimages.blocks.ImageChooserBlock(required=False)), ('paragraph', wagtail.wagtailcore.blocks.RichTextBlock(required=True))))),))),
            ],
            options={
                'verbose_name': 'Business Casual Page (texsite.businesscasual)',
            },
            bases=('texsitecore.basepage',),
        ),
    ]



# -*- coding: utf-8 -*-

from django.core.exceptions import ObjectDoesNotExist

from ..tests import TexsiteTestCase
from texsite.businesscasual.models import BusinessCasualPage


class BusinessCasualTestCase(TexsiteTestCase):
    def setUp(self):
        super(BusinessCasualTestCase, self).setUp()

        try:
            self.business_casual_page = BusinessCasualPage.objects.get(pk=2)
        except ObjectDoesNotExist:
            pass

        self.business_casual_page_response = self.client.get('/business-casual-page/')


class BusinessCasualPageTest(BusinessCasualTestCase):
    fixtures = ['site.json', 'businesscasual.json']

    def test_business_casual_with_minimal_content_rendered(self):
        self.assertInHTML('<div class="brand">Texsite site</div>', str(self.business_casual_page_response.content))
        self.assertInHTML('<div class="address-bar">Business Casual page</div>', str(self.business_casual_page_response.content))



# -*- coding: utf-8 -*-

from wagtail.wagtailcore.blocks import CharBlock, StructBlock, TextBlock
from wagtail.wagtailimages.blocks import ImageChooserBlock


class HeadingBlock(StructBlock):
    title = CharBlock(required=True)
    subtitle = CharBlock(required=False)

    class Meta:
        icon = 'placeholder'


class ImageBlock(StructBlock):
    image = ImageChooserBlock(required=True)
    caption = CharBlock(required=False)

    class Meta:
        icon = 'image'


class IntroBlock(StructBlock):
    keyvisual = ImageChooserBlock(required=False)
    slogan = CharBlock(required=True)

    class Meta:
        icon = 'placeholder'


class QuoteBlock(StructBlock):
    quote = TextBlock(required=True)
    originator = CharBlock(required=False)

    class Meta:
        icon = 'openquote'



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import wagtail.wagtailcore.fields
import wagtail.wagtailcore.blocks
import wagtail.wagtailimages.blocks
import wagtail.wagtaildocs.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('texsitebusinesscasual', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='businesscasualpage',
            name='body',
            field=wagtail.wagtailcore.fields.StreamField((('content', wagtail.wagtailcore.blocks.StructBlock((('heading', wagtail.wagtailcore.blocks.CharBlock(required=True)), ('image', wagtail.wagtailimages.blocks.ImageChooserBlock(required=False)), ('paragraph', wagtail.wagtailcore.blocks.RichTextBlock(required=True))))), ('documents', wagtail.wagtailcore.blocks.StructBlock((('heading', wagtail.wagtailcore.blocks.CharBlock(required=True)), ('paragraph', wagtail.wagtailcore.blocks.RichTextBlock(required=False)), ('files', wagtail.wagtailcore.blocks.ListBlock(wagtail.wagtaildocs.blocks.DocumentChooserBlock(), template='texsitebusinesscasual/blocks/documentlist.html'))))))),
        ),
    ]



# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _

from wagtail.wagtailadmin.edit_handlers import StreamFieldPanel
from wagtail.wagtailcore.fields import StreamField

from texsite.core.models import BasePage

from .blocks import ContactBlock, ContentBlock, DocumentsBlock, PeopleBlock


class BusinessCasualPage(BasePage):
    """Business Casual page"""
    # Page model fields
    body = StreamField([
        ('content', ContentBlock()),
        ('documents', DocumentsBlock()),
        ('people', PeopleBlock()),
        ('contact', ContactBlock())
    ])

    content_panels = BasePage.content_panels + [
        StreamFieldPanel('body'),
    ]

    class Meta:
        verbose_name = _('Business Casual Page') + ' (' + __package__ + ')'



# -*- coding: utf-8 -*-

from django.apps import AppConfig


class TexsiteCleanBlogAppConfig(AppConfig):
    name = 'texsite.cleanblog'
    label = 'texsitecleanblog'
    verbose_name = "texsite clean blog"



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import wagtail.wagtailcore.fields
import wagtail.wagtailcore.blocks
import wagtail.wagtailimages.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('texsitecleanblog', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cleanblogarticlepage',
            name='body',
            field=wagtail.wagtailcore.fields.StreamField([(b'intro', wagtail.wagtailcore.blocks.StructBlock([(b'keyvisual', wagtail.wagtailimages.blocks.ImageChooserBlock(required=False)), (b'slogan', wagtail.wagtailcore.blocks.CharBlock(required=True))])), (b'heading', wagtail.wagtailcore.blocks.StructBlock([(b'title', wagtail.wagtailcore.blocks.CharBlock(required=True)), (b'subtitle', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/heading.html')), (b'paragraph', wagtail.wagtailcore.blocks.RichTextBlock()), (b'image', wagtail.wagtailimages.blocks.ImageChooserBlock(template=b'texsitecleanblog/blocks/image.html')), (b'quote', wagtail.wagtailcore.blocks.StructBlock([(b'quote', wagtail.wagtailcore.blocks.TextBlock(required=True)), (b'originator', wagtail.wagtailcore.blocks.CharBlock(required=False))], template=b'texsitecleanblog/blocks/quote.html'))]),
        ),
    ]



from setuptools import setup, find_packages
from texsite import __version__

# Installation dependencies
install_requires = [
    'django-bootstrap-ui>=0.2,<0.3',
    'wagtail>=1.9,<1.10',
    'wagtailmenus>=2.2,<2.3',
]

# Testing dependencies
testing_extras = [
    'coverage>=4.0.3',
    'flake8>=2.4.1',
]

setup(
    name='texsite',
    version=__version__,
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    license='ISC License (ISCL)',
    description=
        'texsite delivers great and ready-to-use page templates for the modern, flexible and user-focused web content'
        'management system Wagtail CMS backed by the popular Django web framework, both written in Python.',
    long_description=open('README.rst').read(),
    url='https://github.com/texperience/texsite',
    author='Timo Rieber',
    author_email='trieber@texperience.de',
    install_requires=install_requires,
    extras_require={
        'testing': testing_extras,
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.8',
        'Framework :: Django :: 1.9',
        'Framework :: Django :: 1.10',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: ISC License (ISCL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)



# -*- coding: utf-8 -*-

from django.apps import AppConfig


class TexsiteBusinessCasualAppConfig(AppConfig):
    name = 'texsite.businesscasual'
    label = 'texsitebusinesscasual'
    verbose_name = "texsite business casual"
